# DataToWord

## 專案目的

這是一個將資料轉換成文字的專案，可以協助你在進行 RAG 的過程中，將資料類型的檔案轉換成文字，方便後續進行段落查詢。

目前支援的檔案有：

- CSV
- JSON

## 使用方式

### 安裝

```bash
pip install datatoword
```
or

```bash
poetry add datatoword
```

### Quick Start

```python
```

## poetry export requirements.txt

```bash
poetry export -f requirements.txt --output requirements.txt --without-hashes
```